==> opentoonz-dmo_1.5.0.orig.tar.xz: opentoonz-1.5.0/toonz/sources/translations/chinese/image.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN" sourcelanguage="en">
<context>
    <name>AviWriterProperties</name>
    <message>
        <location filename="../../image/avi/tiio_avi.cpp" line="1182"/>
        <source>Codec</source>
        <translation>编码器</translation>
    </message>
    <message>
        <location filename="../../image/avi/tiio_avi.cpp" line="1183"/>
        <source>Uncompressed</source>
        <translation>未压缩</translation>
    </message>
</context>
<context>
    <name>GifWriterProperties</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="257"/>
        <source>Scale</source>
        <translation>缩放</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="258"/>
        <source>Looping</source>
        <translation>循环</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="259"/>
        <source>Generate Palette</source>
        <translation>生成调色板</translation>
    </message>
</context>
<context>
    <name>Mp4WriterProperties</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_mp4.cpp" line="234"/>
        <source>Quality</source>
        <translation>质量</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_mp4.cpp" line="235"/>
        <source>Scale</source>
        <translation>缩放</translation>
    </message>
</context>
<context>
    <name>PngWriterProperties</name>
    <message>
        <location filename="../../image/png/tiio_png.cpp" line="757"/>
        <source>Alpha Channel</source>
        <translation>透明度通道</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_ffmpeg.cpp" line="177"/>
        <source>FFmpeg timed out.
Please check the file for errors.
If the file doesn&apos;t play or is incomplete, 
Please try raising the FFmpeg timeout in Preferences.</source>
        <translation>FFmpeg 已超时。
请查看文件错误。
如果文件不能播放或者不完整，
请在首选项调高 FFmpeg 的超时参数。</translation>
    </message>
</context>
<context>
    <name>SgiWriterProperties</name>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1229"/>
        <source>Bits Per Pixel</source>
        <translation>像素位数</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1230"/>
        <source>24 bits</source>
        <translation>24 位</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1231"/>
        <source>32 bits</source>
        <translation>32 位</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1232"/>
        <source>48 bits</source>
        <translation>48 位</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1233"/>
        <source>64 bits</source>
        <translation>64 位</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1234"/>
        <source>8 bits (Greyscale)</source>
        <translation>8 位(灰阶)</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1235"/>
        <source>Endianess</source>
        <translation>字节序</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1236"/>
        <source>Big Endian</source>
        <translatorcomment>高地址位在整个地址位的前端低位优先</translatorcomment>
        <translation>高位优先</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1237"/>
        <source>Little Endian</source>
        <translatorcomment>代表低地址位在整个地址位的前端</translatorcomment>
        <translation>低位优先</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1238"/>
        <source>RLE-Compressed</source>
        <translation>RLE 压缩</translation>
    </message>
</context>
<context>
    <name>SpriteWriterProperties</name>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="313"/>
        <source>Top Padding</source>
        <translation>上边距</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="314"/>
        <source>Bottom Padding</source>
        <translation>下边距</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="315"/>
        <source>Left Padding</source>
        <translation>左边距</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="316"/>
        <source>Right Padding</source>
        <translation>右边距</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="317"/>
        <source>Scale</source>
        <translation>缩放</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="318"/>
        <source>Format</source>
        <translation>格式</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="319"/>
        <source>Grid</source>
        <translation>格子</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="320"/>
        <source>Vertical</source>
        <translation>垂直</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="321"/>
        <source>Horizontal</source>
        <translation>水平</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="322"/>
        <source>Individual</source>
        <translation>独立</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="323"/>
        <source>Trim Empty Space</source>
        <translation>剪切空白</translation>
    </message>
</context>
<context>
    <name>SvgWriterProperties</name>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1969"/>
        <source>Stroke Mode</source>
        <translation>描边模式</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1970"/>
        <source>Outline Quality</source>
        <translation>轮廓质量</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1971"/>
        <source>Centerline</source>
        <translation>中心线</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1972"/>
        <source>Outline</source>
        <translation>轮廓</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1973"/>
        <source>High</source>
        <translation>高</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1974"/>
        <source>Medium</source>
        <translation>中</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1975"/>
        <source>Low</source>
        <translation>低</translation>
    </message>
</context>
<context>
    <name>TgaWriterProperties</name>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="523"/>
        <source>Bits Per Pixel</source>
        <translation>像素的位数</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="524"/>
        <source>16 bits</source>
        <translation>16 位</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="525"/>
        <source>24 bits</source>
        <translation>24 位</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="526"/>
        <source>32 bits</source>
        <translation>32 位</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="527"/>
        <source>Compression</source>
        <translation>压缩</translation>
    </message>
</context>
<context>
    <name>TifWriterProperties</name>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="730"/>
        <source>Byte Ordering</source>
        <translation>字节顺序</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="731"/>
        <source>Compression Type</source>
        <translation>压缩方式</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="732"/>
        <source>Bits Per Pixel</source>
        <translation>像素的位数</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="733"/>
        <source>24(RGB)</source>
        <translation>24(RGB)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="734"/>
        <source>48(RGB)</source>
        <translation>48(RGB)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="735"/>
        <source> 1(BW)</source>
        <translation> 1(黑白)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="736"/>
        <source> 8(GREYTONES)</source>
        <translation> 8(灰阶)</translation>
    </message>
    <message>
        <source>32(RGBM)</source>
        <translation type="vanished">32(RGBM)</translation>
    </message>
    <message>
        <source>64(RGBM)</source>
        <translation type="vanished">64(RGBM)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="737"/>
        <source>32(RGBA)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="738"/>
        <source>64(RGBA)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="739"/>
        <source>Orientation</source>
        <translation>方向</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="740"/>
        <source>Top Left</source>
        <translation>上左</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="741"/>
        <source>Top Right</source>
        <translation>上右</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="742"/>
        <source>Bottom Right</source>
        <translation>下右</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="743"/>
        <source>Bottom Left</source>
        <translation>下左</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="744"/>
        <source>Left Top</source>
        <translation>左上</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="745"/>
        <source>Left Bottom</source>
        <translation>左下</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="746"/>
        <source>Right Top</source>
        <translation>右上</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="747"/>
        <source>Right Bottom</source>
        <translation>右下</translation>
    </message>
</context>
<context>
    <name>WebmWriterProperties</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_webm.cpp" line="235"/>
        <source>Quality</source>
        <translation>质量</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_webm.cpp" line="236"/>
        <source>Scale</source>
        <translation>缩放</translation>
    </message>
</context>
</TS>

==> opentoonz-dmo_1.6.0.orig.tar.xz: opentoonz-1.6.0/toonz/sources/translations/chinese/image.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN" sourcelanguage="en_US">
<context>
    <name>AviWriterProperties</name>
    <message>
        <location filename="../../image/avi/tiio_avi.cpp" line="1182"/>
        <source>Codec</source>
        <translation>编码器</translation>
    </message>
    <message>
        <location filename="../../image/avi/tiio_avi.cpp" line="1183"/>
        <source>Uncompressed</source>
        <translation>未压缩</translation>
    </message>
</context>
<context>
    <name>ExrWriterProperties</name>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="227"/>
        <source>Bits Per Pixel</source>
        <translation>像素位数</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="228"/>
        <source>48(RGB Half Float)</source>
        <translation>48(RGB 半浮点)</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="229"/>
        <source>64(RGBA Half Float)</source>
        <translation>64(RGBA 半浮点)</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="231"/>
        <source>Compression Type</source>
        <translation>压缩方式</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="233"/>
        <source>No compression</source>
        <translation>不压缩</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="236"/>
        <source>Run Length Encoding (RLE)</source>
        <translation>行程编码</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="239"/>
        <source>ZIP compression per Scanline (ZIPS)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="242"/>
        <source>ZIP compression per scanline band (ZIP)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="245"/>
        <source>PIZ-based wavelet compression (PIZ)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="247"/>
        <source>Storage Type</source>
        <translation>存储类型</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="248"/>
        <source>Scan-line based</source>
        <translation>基于扫描线</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="249"/>
        <source>Tile based</source>
        <translation>基于块</translation>
    </message>
</context>
<context>
    <name>GifWriterProperties</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="310"/>
        <source>Global Palette</source>
        <translation>全局调色板</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="311"/>
        <source>Global Palette + Sierra Dither</source>
        <translation>全局调色板 + Sierra抖动</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="312"/>
        <source>Global Palette + Bayer2 Dither</source>
        <translation>全局调色版 + 拜尔2抖动</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="313"/>
        <source>Global Palette + Bayer1 Dither</source>
        <translation>全局调色版 + 拜尔1抖动</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="314"/>
        <source>Diff Palette</source>
        <translation>差异调色板</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="315"/>
        <source>Diff Palette + Sierra Dither</source>
        <translation>差异调色板 + Sierra抖动</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="316"/>
        <source>Diff Palette + Bayer2 Dither</source>
        <translation>差异调色板 + 拜尔1抖动</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="317"/>
        <source>Diff Palette + Bayer1 Dither</source>
        <translation>差异调色板 + 拜尔1抖动</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="318"/>
        <source>New Pal Per Frame</source>
        <translation>新建每帧调色板</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="319"/>
        <source>New Pal Per Frame + Sierra Dither</source>
        <translation>新建每帧调色板 + Sierra抖动</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="320"/>
        <source>New Pal Per Frame + Bayer2 Dither</source>
        <translation>新建每帧调色板 + 拜尔2抖动</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="321"/>
        <source>New Pal Per Frame + Bayer1 Dither</source>
        <translation>新建每帧调色板 + 拜尔1抖动</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="322"/>
        <source>Opaque, Dither, 256 Colors Only</source>
        <translation>不透明，抖动，仅256色</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="335"/>
        <source>Scale</source>
        <translation>缩放</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="336"/>
        <source>Looping</source>
        <translation>循环</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="337"/>
        <source>Mode</source>
        <translation>模式</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="338"/>
        <source>Max Colors</source>
        <translation>最大色数</translation>
    </message>
    <message>
        <source>Generate Palette</source>
        <translation type="vanished">生成调色板</translation>
    </message>
</context>
<context>
    <name>Mp4WriterProperties</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_mp4.cpp" line="234"/>
        <source>Quality</source>
        <translation>质量</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_mp4.cpp" line="235"/>
        <source>Scale</source>
        <translation>缩放</translation>
    </message>
</context>
<context>
    <name>PngWriterProperties</name>
    <message>
        <location filename="../../image/png/tiio_png.cpp" line="757"/>
        <source>Alpha Channel</source>
        <translation>透明度通道</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_ffmpeg.cpp" line="213"/>
        <source>FFmpeg returned error-code: %1</source>
        <translation>FFmpeg 返回的错误编码: %1</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_ffmpeg.cpp" line="217"/>
        <source>FFmpeg timed out.
Please check the file for errors.
If the file doesn&apos;t play or is incomplete, 
Please try raising the FFmpeg timeout in Preferences.</source>
        <translation>FFmpeg 已超时。
请查看文件错误。
如果文件不能播放或者不完整，
请在首选项调高 FFmpeg 的超时参数。</translation>
    </message>
</context>
<context>
    <name>SgiWriterProperties</name>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1229"/>
        <source>Bits Per Pixel</source>
        <translation>像素位数</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1230"/>
        <source>24 bits</source>
        <translation>24 位</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1231"/>
        <source>32 bits</source>
        <translation>32 位</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1232"/>
        <source>48 bits</source>
        <translation>48 位</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1233"/>
        <source>64 bits</source>
        <translation>64 位</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1234"/>
        <source>8 bits (Greyscale)</source>
        <translation>8 位(灰阶)</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1235"/>
        <source>Endianess</source>
        <translation>字节序</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1236"/>
        <source>Big Endian</source>
        <translatorcomment>高地址位在整个地址位的前端低位优先</translatorcomment>
        <translation>高位优先</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1237"/>
        <source>Little Endian</source>
        <translatorcomment>代表低地址位在整个地址位的前端</translatorcomment>
        <translation>低位优先</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1238"/>
        <source>RLE-Compressed</source>
        <translation>RLE 压缩</translation>
    </message>
</context>
<context>
    <name>SpriteWriterProperties</name>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="313"/>
        <source>Top Padding</source>
        <translation>上边距</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="314"/>
        <source>Bottom Padding</source>
        <translation>下边距</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="315"/>
        <source>Left Padding</source>
        <translation>左边距</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="316"/>
        <source>Right Padding</source>
        <translation>右边距</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="317"/>
        <source>Scale</source>
        <translation>缩放</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="318"/>
        <source>Format</source>
        <translation>格式</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="319"/>
        <source>Grid</source>
        <translation>格子</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="320"/>
        <source>Vertical</source>
        <translation>垂直</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="321"/>
        <source>Horizontal</source>
        <translation>水平</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="322"/>
        <source>Individual</source>
        <translation>独立</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="323"/>
        <source>Trim Empty Space</source>
        <translation>剪切空白</translation>
    </message>
</context>
<context>
    <name>SvgWriterProperties</name>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1969"/>
        <source>Stroke Mode</source>
        <translation>描边模式</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1970"/>
        <source>Outline Quality</source>
        <translation>轮廓质量</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1971"/>
        <source>Centerline</source>
        <translation>中心线</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1972"/>
        <source>Outline</source>
        <translation>轮廓</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1973"/>
        <source>High</source>
        <translation>高</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1974"/>
        <source>Medium</source>
        <translation>中</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1975"/>
        <source>Low</source>
        <translation>低</translation>
    </message>
</context>
<context>
    <name>TgaWriterProperties</name>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="523"/>
        <source>Bits Per Pixel</source>
        <translation>像素位数</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="524"/>
        <source>16 bits</source>
        <translation>16 位</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="525"/>
        <source>24 bits</source>
        <translation>24 位</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="526"/>
        <source>32 bits</source>
        <translation>32 位</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="527"/>
        <source>Compression</source>
        <translation>压缩</translation>
    </message>
</context>
<context>
    <name>TifWriterProperties</name>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="730"/>
        <source>Byte Ordering</source>
        <translation>字节顺序</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="731"/>
        <source>Compression Type</source>
        <translation>压缩方式</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="732"/>
        <source>Bits Per Pixel</source>
        <translation>像素位数</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="733"/>
        <source>24(RGB)</source>
        <translation>24(RGB)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="734"/>
        <source>48(RGB)</source>
        <translation>48(RGB)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="735"/>
        <source> 1(BW)</source>
        <translation> 1(黑白)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="736"/>
        <source> 8(GREYTONES)</source>
        <translation> 8(灰阶)</translation>
    </message>
    <message>
        <source>32(RGBM)</source>
        <translation type="vanished">32(RGBM)</translation>
    </message>
    <message>
        <source>64(RGBM)</source>
        <translation type="vanished">64(RGBM)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="737"/>
        <source>32(RGBA)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="738"/>
        <source>64(RGBA)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="739"/>
        <source>Orientation</source>
        <translation>方向</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="740"/>
        <source>Top Left</source>
        <translation>上左</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="741"/>
        <source>Top Right</source>
        <translation>上右</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="742"/>
        <source>Bottom Right</source>
        <translation>下右</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="743"/>
        <source>Bottom Left</source>
        <translation>下左</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="744"/>
        <source>Left Top</source>
        <translation>左上</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="745"/>
        <source>Left Bottom</source>
        <translation>左下</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="746"/>
        <source>Right Top</source>
        <translation>右上</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="747"/>
        <source>Right Bottom</source>
        <translation>右下</translation>
    </message>
</context>
<context>
    <name>WebmWriterProperties</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_webm.cpp" line="235"/>
        <source>Quality</source>
        <translation>质量</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_webm.cpp" line="236"/>
        <source>Scale</source>
        <translation>缩放</translation>
    </message>
</context>
</TS>
